from __future__ import unicode_literals

from django.db import models


class KeyValueSetting(models.Model):
    key = models.CharField(
        unique=True,
        max_length=255)
    value = models.TextField()
    notes = models.TextField(
        blank=True)
    added_on = models.DateTimeField(
        auto_now_add=True)
    updated_on = models.DateTimeField(
        auto_now=True)

    def __str__(self):
        return self.key

    class Meta:
        verbose_name = 'key value setting'
        verbose_name_plural = 'key value settings'



# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2018-01-03 10:24
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='KeyValueSetting',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('key', models.CharField(max_length=255, unique=True)),
                ('value', models.TextField()),
                ('notes', models.TextField(blank=True)),
                ('added_on', models.DateTimeField(auto_now_add=True)),
                ('updated_on', models.DateTimeField(auto_now=True)),
            ],
            options={
                'verbose_name': 'key value setting',
                'verbose_name_plural': 'key value settings',
            },
        ),
    ]



from setuptools import find_packages, setup
# Read: http://peterdowns.com/posts/first-time-with-pypi.html

setup(
    name='kv_settings',
    packages=find_packages(),
    include_package_data=True,
    version='0.1.1',
    description='Django Key Value Settings',
    author='Eshan Das',
    author_email='eshandasnit@gmail.com',
    url='https://github.com/eshandas/django_key_value_settings',  # use the URL to the github repo
    download_url='https://github.com/eshandas/django_key_value_settings/archive/0.1.1.tar.gz',  # Create a tag in github
    keywords=['django', 'key value', 'settings'],
    classifiers=[],
    install_requires=[
        'Django>=1.7'],
)
